Learn R Programming

moodlequiz (version 0.2.0)

choices: Create a set of choices for single or multiple choice questions

Description

Create a set of choices for single or multiple choice questions

Usage

choices(options, answer)

Value

A named vector of choices suitable for use with cloze_singlechoice() and cloze_multichoice()

Arguments

options

A character vector of selectable choices

answer

A character vector of the correct answers

See Also

cloze_singlechoice(), cloze_multichoice()