View source: R/count_answers.R
| count_answers | R Documentation |
count_answers() counts student's answers from every "Response" columns from from a Moodle Responses report(s).
Answers from Moodle's quiz can be one of 3 types: single answered, multiple answered, or embedded answers (Cloze).
Each of these answers types formatted differently in the "Response" column.
count_answers() knows each type of answers and count the answers by the best counting method it thinks.
count_answers(
data,
count_type = c("auto", "single", "multi", "cloze"),
sort = TRUE,
round_digits = 2
)
data |
A data.frame of Moodle Responses report(s) (not Grades report) |
count_type |
A character indicate type of counting methods. Must be one of:
|
sort |
(Logical) |
round_digits |
Integer to round the counted percentage or |
A data.frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.