powered by
Create a set of choices for single or multiple choice questions
choices(options, answer)
A named vector of choices suitable for use with cloze_singlechoice() and cloze_multichoice()
cloze_singlechoice()
cloze_multichoice()
A character vector of selectable choices
A character vector of the correct answers
cloze_singlechoice(), cloze_multichoice()